package main

import (
	"code.beefchicken.com/trimtools/stfw"
	"flag"
	"fmt"
	"os"
)

func main() {

	var combine, split bool
	flag.BoolVar(&combine, "c", false, "combine ROM images")
	flag.BoolVar(&split, "s", false, "split ROM images")

	flag.Parse()

	if len(flag.Args()) != 3 || !(combine || split) || combine && split {
		fmt.Printf("Usage:\n")
		fmt.Printf("    romknife -c <low> <high> <combined>\n")
		fmt.Printf("    romknife -s <combined> <low> <high>\n")
		os.Exit(1)
	}

	if combine {
		low, err := os.ReadFile(flag.Arg(0))
		if err != nil {
			die("Unable to read '%s': %v. Aborting.\n", flag.Arg(0), err)
		}

		high, err := os.ReadFile(flag.Arg(1))
		if err != nil {
			die("Unable to read '%s': %v. Aborting.\n", flag.Arg(1), err)
		}

		if len(low) != len(high) {
			die("Low and High file sizes must match. Aborting.\n")
		}

		combined := stfw.MergeBin(low, high)

		err = os.WriteFile(flag.Arg(2), combined, 0644)
		if err != nil {
			die("Unable to write output to '%s': %v. Aborting.\n", flag.Arg(2), err)
		}
	}

	if split {
		combined, err := os.ReadFile(flag.Arg(0))
		if err != nil {
			die("Unable to read '%s': %v. Aborting.\n", flag.Arg(0), err)
		}

		if len(combined)%2 != 0 {
			die("Combined must have even size. Aborting.\n")
		}

		low, high := stfw.SplitBin(combined)

		err = os.WriteFile(flag.Arg(1), low, 0644)
		if err != nil {
			die("Unable to write file '%s': %v. Aborting.\n", flag.Arg(1), err)
		}

		err = os.WriteFile(flag.Arg(2), high, 0644)
		if err != nil {
			die("Unable to write file '%s': %v. Aborting.\n", flag.Arg(2), err)
		}

	}

}

func die(format string, a ...interface{}) {
	fmt.Fprintf(os.Stderr, format, a...)
	os.Exit(1)
}
